@@ -206,142 +206,53 @@ organize_glmnet_prob <- function(x, object) {
   res
 }
 
-# ------------------------------------------------------------------------------
-# glmnet call stack for logistic regression using `predict` when object has
-# classes "_lognet" and "model_fit" (for class predictions):
-#
-#  predict()
-# 	predict._lognet(penalty = NULL)    <-- checks and sets penalty
-#    predict.model_fit()               <-- checks for extra vars in ...
-#     predict_class()
-#      predict_class._lognet()
-#       predict_class.model_fit()
-#        predict.lognet()
-
-
-# glmnet call stack for logistic regression using `multi_predict` when object has
-# classes "_lognet" and "model_fit" (for class predictions):
-#
-# 	multi_predict()
-#    multi_predict._lognet(penalty = NULL)
-#      predict._lognet(multi = TRUE)           <-- checks and sets penalty
-#       predict.model_fit()                    <-- checks for extra vars in ...
-#        predict_raw()
-#         predict_raw._lognet()
-#          predict_raw.model_fit(opts = list(s = penalty))
-#           predict.lognet()
-
 # ------------------------------------------------------------------------------
 
 #' @export
-predict._lognet <- function(object, new_data, type = NULL, opts = list(), penalty = NULL, multi = FALSE, ...) {
-  if (any(names(enquos(...)) == "newdata"))
-    rlang::abort("Did you mean to use `new_data` instead of `newdata`?")
-
-  # See discussion in https://github.com/tidymodels/parsnip/issues/195
-  if (is.null(penalty) & !is.null(object$spec$args$penalty)) {
-    penalty <- object$spec$args$penalty
-  }
-
-  object$spec$args$penalty <- .check_glmnet_penalty_predict(penalty, object, multi)
-
-  object$spec <- eval_args(object$spec)
-  predict.model_fit(object, new_data = new_data, type = type, opts = opts, ...)
-}
-
+predict._lognet <- predict_glmnet
 
 #' @export
 #' @rdname multi_predict
-multi_predict._lognet <-
-  function(object, new_data, type = NULL, penalty = NULL, ...) {
-    if (any(names(enquos(...)) == "newdata"))
-      rlang::abort("Did you mean to use `new_data` instead of `newdata`?")
+multi_predict._lognet <- multi_predict_glmnet
 
-    if (is_quosure(penalty))
-      penalty <- eval_tidy(penalty)
-
-    dots <- list(...)
-
-    if (is.null(penalty)) {
-      # See discussion in https://github.com/tidymodels/parsnip/issues/195
-      if (!is.null(object$spec$args$penalty)) {
-        penalty <- object$spec$args$penalty
-      } else {
-        penalty <- object$fit$lambda
-      }
+format_glmnet_multi_logistic_reg <- function(pred, penalty, type, lvl) {
+  param_key <- tibble(group = colnames(pred), penalty = penalty)
+  pred <- as_tibble(pred)
+  pred$.row <- 1:nrow(pred)
+  pred <- gather(pred, group, .pred_class, -.row)
+  if (type == "class") {
+    pred[[".pred_class"]] <- factor(pred[[".pred_class"]], levels = lvl)
+  } else {
+    if (type == "response") {
+      pred[[".pred2"]] <- 1 - pred[[".pred_class"]]
+      names(pred) <- c(".row", "group", paste0(".pred_", rev(lvl)))
+      pred <- pred[, c(".row", "group", paste0(".pred_", lvl))]
     }
-
-    dots$s <- penalty
-
-    if (is.null(type))
-      type <- "class"
-    if (!(type %in% c("class", "prob", "link", "raw"))) {
-      rlang::abort("`type` should be either 'class', 'link', 'raw', or 'prob'.")
-    }
-    if (type == "prob")
-      dots$type <- "response"
-    else
-      dots$type <- type
-
-    object$spec <- eval_args(object$spec)
-    pred <- predict.model_fit(object, new_data = new_data, type = "raw", opts = dots)
-    param_key <- tibble(group = colnames(pred), penalty = penalty)
-    pred <- as_tibble(pred)
-    pred$.row <- 1:nrow(pred)
-    pred <- gather(pred, group, .pred_class, -.row)
-    if (dots$type == "class") {
-      pred[[".pred_class"]] <- factor(pred[[".pred_class"]], levels = object$lvl)
-    } else {
-      if (dots$type == "response") {
-        pred[[".pred2"]] <- 1 - pred[[".pred_class"]]
-        names(pred) <- c(".row", "group", paste0(".pred_", rev(object$lvl)))
-        pred <- pred[, c(".row", "group", paste0(".pred_", object$lvl))]
-      }
-    }
-    if (utils::packageVersion("dplyr") >= "1.0.99.9000") {
-      pred <- full_join(param_key, pred, by = "group", multiple = "all")
-    } else {
-      pred <- full_join(param_key, pred, by = "group")
-    }
-    pred$group <- NULL
-    pred <- arrange(pred, .row, penalty)
-    .row <- pred$.row
-    pred$.row <- NULL
-    pred <- split(pred, .row)
-    names(pred) <- NULL
-    tibble(.pred = pred)
   }
-
-
+  if (utils::packageVersion("dplyr") >= "1.0.99.9000") {
+    pred <- full_join(param_key, pred, by = "group", multiple = "all")
+  } else {
+    pred <- full_join(param_key, pred, by = "group")
+  }
+  pred$group <- NULL
+  pred <- arrange(pred, .row, penalty)
+  .row <- pred$.row
+  pred$.row <- NULL
+  pred <- split(pred, .row)
+  names(pred) <- NULL
+  tibble(.pred = pred)
+}
 
 
 
 #' @export
-predict_class._lognet <- function(object, new_data, ...) {
-  if (any(names(enquos(...)) == "newdata"))
-    rlang::abort("Did you mean to use `new_data` instead of `newdata`?")
-
-  object$spec <- eval_args(object$spec)
-  predict_class.model_fit(object, new_data = new_data, ...)
-}
+predict_class._lognet <- predict_class_glmnet
 
 #' @export
-predict_classprob._lognet <- function(object, new_data, ...) {
-  if (any(names(enquos(...)) == "newdata"))
-    rlang::abort("Did you mean to use `new_data` instead of `newdata`?")
-
-  object$spec <- eval_args(object$spec)
-  predict_classprob.model_fit(object, new_data = new_data, ...)
-}
+predict_classprob._lognet <- predict_classprob_glmnet
 
 #' @export
-predict_raw._lognet <- function(object, new_data, opts = list(), ...) {
-  if (any(names(enquos(...)) == "newdata"))
-    rlang::abort("Did you mean to use `new_data` instead of `newdata`?")
-
-  object$spec <- eval_args(object$spec)
-  predict_raw.model_fit(object, new_data = new_data, opts = opts, ...)
-}
+predict_raw._lognet <- predict_raw_glmnet
 
 # ------------------------------------------------------------------------------
 
