@@ -47,8 +47,10 @@ surv_reg <- function(mode = "regression", engine = "survival", dist = NULL) {
       args = args,
       eng_args = NULL,
       mode = mode,
+      user_specified_mode = !missing(mode),
       method = NULL,
-      engine = engine
+      engine = engine,
+      user_specified_engine = !missing(engine)
     )
   }
 
