@@ -41,8 +41,10 @@ survival_reg <- function(mode = "censored regression", engine = "survival", dist
     args = args,
     eng_args = NULL,
     mode = mode,
+    user_specified_mode = !missing(mode),
     method = NULL,
-    engine = engine
+    engine = engine,
+    user_specified_engine = !missing(engine)
   )
 }
 
