@@ -1,17 +1,7 @@
-library(testthat)
-library(parsnip)
-library(tibble)
-library(dplyr)
-
-# ------------------------------------------------------------------------------
-
-context("boosted tree execution with C5.0")
-source(test_path("helper-objects.R"))
-
 lending_club <- head(lending_club, 200)
 lending_club_fail <-
   lending_club %>%
-  mutate(bad = Inf, miss = NA)
+  dplyr::mutate(bad = Inf, miss = NA)
 num_pred <- c("funded_amnt", "annual_inc", "num_il_tl")
 lc_basic <-
   boost_tree(mode = "classification")  %>%
@@ -32,7 +22,6 @@ test_that('C5.0 execution', {
     ),
     regexp = NA
   )
-  expect_output(print(res), "parsnip model object")
 
   expect_error(
     res <- fit_xy(
@@ -65,7 +54,7 @@ test_that('C5.0 execution', {
     data = lending_club_fail,
     control = caught_ctrl
   )
-  expect_true(inherits(C5.0_form_catch$fit, "try-error"))
+  expect_true(inherits(extract_fit_engine(C5.0_form_catch), "try-error"))
 
   # Model fails
   C5.0_xy_catch <- fit_xy(
@@ -74,7 +63,7 @@ test_that('C5.0 execution', {
     x = lending_club_fail[, "miss"],
     y = lending_club_fail$Class
   )
-  expect_true(inherits(C5.0_xy_catch$fit, "try-error"))
+  expect_true(inherits(extract_fit_engine(C5.0_xy_catch), "try-error"))
 })
 
 test_that('C5.0 prediction', {
@@ -88,7 +77,7 @@ test_that('C5.0 prediction', {
     control = ctrl
   )
 
-  xy_pred <- predict(classes_xy$fit, newdata = lending_club[1:7, num_pred])
+  xy_pred <- predict(extract_fit_engine(classes_xy), newdata = lending_club[1:7, num_pred])
   expect_equal(xy_pred, predict(classes_xy, lending_club[1:7, num_pred])$.pred_class)
 
 })
@@ -104,7 +93,7 @@ test_that('C5.0 probabilities', {
     control = ctrl
   )
 
-  xy_pred <- predict(classes_xy$fit, newdata = as.data.frame(lending_club[1:7, num_pred]), type = "prob")
+  xy_pred <- predict(extract_fit_engine(classes_xy), newdata = as.data.frame(lending_club[1:7, num_pred]), type = "prob")
   xy_pred <- as_tibble(xy_pred)
   names(xy_pred) <- c(".pred_bad", ".pred_good")
   expect_equal(xy_pred, predict(classes_xy, lending_club[1:7, num_pred], type = "prob"))
@@ -126,11 +115,11 @@ test_that('submodel prediction', {
     set_engine("C5.0", control = C5.0Control(earlyStopping = FALSE)) %>%
     fit(churn ~ ., data = wa_churn[-(1:4), c("churn", vars)])
 
-  pred_class <- predict(class_fit$fit, wa_churn[1:4, vars], trials = 4, type = "prob")
+  pred_class <- predict(extract_fit_engine(class_fit), wa_churn[1:4, vars], trials = 4, type = "prob")
 
   mp_res <- multi_predict(class_fit, new_data = wa_churn[1:4, vars], trees = 4, type = "prob")
   mp_res <- do.call("rbind", mp_res$.pred)
-  expect_equal(mp_res[[".pred_No"]], unname(pred_class[, "No"]))
+  expect_equal(mp_res[[".pred_No"]], pred_class[, "No"], ignore_attr = TRUE)
 
   expect_error(
     multi_predict(class_fit, newdata = wa_churn[1:4, vars], trees = 4, type = "prob"),
@@ -162,7 +151,7 @@ test_that('argument checks for data dimensions', {
     "1000 samples were requested"
   )
 
-  expect_equal(f_fit$fit$control$minCases,  nrow(penguins))
-  expect_equal(xy_fit$fit$control$minCases, nrow(penguins))
+  expect_equal(extract_fit_engine(f_fit)$control$minCases,  nrow(penguins))
+  expect_equal(extract_fit_engine(xy_fit)$control$minCases, nrow(penguins))
 
 })
